MinePI
======

.. image:: https://readthedocs.org/projects/minepi/badge/?version=latest

MinePI is an all in one Minecraft skin render library written in Python.

Docs
----

https://minepi.readthedocs.io/en/latest/

Contribute
----------

- Issue Tracker: github.com/benno1237/MinePI/issues
- Source Code: github.com/benno1237/MinePI

Support
-------

If you are having issues, please let us know.
Either open an Issue or contact me (Benno#8969) on Discord

License
-------

The project is licensed under the MIT license.
